#
# spec file for package crda
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d }
%define skip_python2 1

Name:           crda
VCS: https://src.suse.de/SLFO-pool/crda#4893ee08213fe462ab2414d02bad62ecebcfed4dfaed767a2f5ba32d5769a7c9
Summary:        802.11 central regulatory domain agent
License:        SUSE-Copyleft-Next-0.3.0
Group:          Hardware/Wifi
URL:            https://wireless.wiki.kernel.org/en/developers/Regulatory/CRDA
Version:        4.14
Release:        160000.1.10
Source0:        https://git.kernel.org/pub/scm/linux/kernel/git/mcgrof/crda.git/snapshot/crda-%{version}.tar.gz
Source1:        crda.default
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libgcrypt-devel
BuildRequires:  pkg-config
BuildRequires:  python3
BuildRequires:  python3-pycrypto
BuildRequires:  wireless-regdb
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(udev)
Requires:       wireless-regdb
Supplements:    kernel >= 2.6.29
# PATCH-FIX-OPENSUSE gcc6-fix-errors.patch -- Fix errors seen by GCC6.
Patch0:         gcc6-fix-errors.patch
# PATCH-FIX-OPENSUSE python2 is gone, port to python3
Patch1:         crda-python3.patch
# PATCH-FIX-UPSTREAM crda-67f1e6ddbdfade357e234c9d58a30fe0a283fe60.patch
Patch2:         crda-67f1e6ddbdfade357e234c9d58a30fe0a283fe60.patch
# PATCH-FIX-UPSTREAM crda-f4ef2531698fb9ba006e8b31a223b3269be8bc7c.patch
Patch3:         crda-f4ef2531698fb9ba006e8b31a223b3269be8bc7c.patch
# PATCH-FIX-SUSE crda-default.patch
Patch4:         crda-default.patch

%description
The crda binary provides access to the wireless-regdb to the kernel
through udev.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
# make install calls 'ldconfig' and fails if it cannot run it...
ln -s /bin/true ldconfig

%build
export CFLAGS="%{optflags}"
make all_noverify %{?_smp_mflags} V=1

%install
# to find ldconfig...
export PATH=.:$PATH
make DESTDIR=$RPM_BUILD_ROOT SBINDIR=%{_sbindir}/ UDEV_RULE_DIR=%{_udevrulesdir} LIBDIR=%{_libdir} install
mkdir -p %{buildroot}%{_prefix}%{_sysconfdir}/default
install -m 644 %{S:1} %{buildroot}%{_prefix}%{_sysconfdir}/default/%{name}
%if 0%{?suse_version} < 1550
mkdir $RPM_BUILD_ROOT/sbin
ln -sf %{_sbindir}/{crda,regdbdump} $RPM_BUILD_ROOT/sbin
%endif

# clean up unneeded stuff...
rm -r %{buildroot}/usr/include/reglib

%files
%defattr(-,root,root)
%_sbindir/crda
%_sbindir/regdbdump
%_libdir/libreg.so
%if 0%{?suse_version} < 1550
/sbin/crda
/sbin/regdbdump
%endif
%if 0%{?suse_version} < 1550
%dir %{_prefix}%{_sysconfdir}/
%dir %{_prefix}%{_sysconfdir}/default/
%endif
%{_prefix}%{_sysconfdir}/default/%{name}
%{_udevrulesdir}/85-regulatory.rules
%{_mandir}/man8/crda.8.gz
%{_mandir}/man8/regdbdump.8.gz

%post
%{?udev_rules_update:%udev_rules_update}

%changelog
* Tue Dec 27 2022 lnussel@suse.com
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Tue Dec  1 2020 werner@suse.de
- Correct upstream URL and upstream release URL
* Mon Nov 30 2020 werner@suse.de
- Add patch crda-default.patch as well as template file crda.default
  for /usr/etc/default/crda to support WLAN USB dongles as well as
  mostly raspberry WLAN drivers not knowing about kernel builtin
  support for WLAN regular country domains (boo#1179308)
* Tue Nov 17 2020 lnussel@suse.de
- prepare usrmerge (boo#1029961)
* Mon Aug 17 2020 ro@suse.de
- update to 4.14 and update home URL to use the github project
  - fix keys defined but not used error
- add patch from upstream
  crda-67f1e6ddbdfade357e234c9d58a30fe0a283fe60.patch
  - add URLs to README
- add patch from upstream
  crda-f4ef2531698fb9ba006e8b31a223b3269be8bc7c.patch
  - add legacy note to README
  - ## CRDA is no longer needed as of kernel v4.15
* Thu Mar 12 2020 ro@suse.de
- add patch crda-python3.patch to build using python3
  it is actually only used for a small helper script splitting
  pem files to individual keys
* Sat Jun  3 2017 meissner@suse.com
- adjust Makefile patch to not include CFLAGS on linker line,
  this indirectly enables PIE support.
* Wed May 25 2016 martin.liska@suse.com
- Add gcc6-fix-errors.patch to remove errors seen by GCC6.
* Sun Jun 28 2015 seife+obs@b1-systems.com
- update to version 3.18:
  * user visible: add pubkey of new wireless-regdb maintainer to
    make crda work at all with newer wireless-regdb
  * synchronize code with latest kernel changes
  * crda: add AUTO-BW rule flag support
  * crda: parse/print CAC time
  * code restructuring and bug fixes
  * ** License is now copyleft-next-0.3.0 ***
- packaging:
  * add V=1 to make calls for rpmlint happiness
  * use %%%%optflags for compilation
  * shared library libreg.so is now used by the tools
* Sun Nov 24 2013 crrodriguez@opensuse.org
- use libnl3 which is now supported
* Sat Nov 23 2013 crrodriguez@opensuse.org
- update to 1.1.3 release (no changelog)
- run %%udev_rules_update in %%post if defined
- Correct _udevrulesdir definition for old distros
* Fri Mar 22 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with udev rules directory new location.
* Thu Sep 13 2012 cfarrell@suse.com
- license update: ISC
  License is ISC, not BSD-3-Clause
* Sun Sep  9 2012 p.drouand@gmail.com
- update to 1.1.2 release
* Tue Feb 28 2012 pcerny@suse.com
- use correct filepath in udev rule
* Sat Feb  4 2012 rschweikert@suse.com
- put files in /usr tree (UsrMerge project)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri Sep 16 2011 jengelh@medozas.de
- Select libnl-1_1-devel
* Fri Mar  5 2010 ro@suse.de
- update to 1.1.1 release
* Sat Oct 10 2009 crrodriguez@opensuse.org
- update to git200910101747, fix build
* Tue Jul 28 2009 aj@suse.de
- Update to crda 1.1.0:
  * make openssl keys 64-bit safe
* Mon Mar  2 2009 hschaa@suse.de
- Add "Supplements: kernel" and "Requires: wireless-regdb"
* Mon Feb  9 2009 hschaa@suse.de
- Update to 1.0.1
- Needed for fate#305301
* Wed Jan 24 2007 helmut.schaa@googlemail.com
- Initial package
